Subject: [PATCH 20/21] gnu: python-redis: Ignore i686 failing test.

From: Nicolas Graves <[email-masked]>
Date: Sun, 6 Apr 2025 14:37:22 +0200

* gnu/packages/databases.scm (python-redis)
[arguments]{test-flags}: Ignore i686 failing test.
---
 gnu/packages/databases.scm | 37 +++++++++++++++++++++----------------
 1 file changed, 21 insertions(+), 16 deletions(-)

diff --git a/gnu/packages/databases.scm b/gnu/packages/databases.scm
index 1aebf982ae..a7c83e5ea3 100644
--- a/gnu/packages/databases.scm
+++ b/gnu/packages/databases.scm
@@ -4562,22 +4562,27 @@ (define-public python-redis
                              "and not ssl "
                              "and not graph")
               "-k" (string-join
-                    (list
-                     ;; The autoclaim test fails with "AssertionError: assert
-                     ;; [b'0-0', [], []] == [b'0-0', []]".
-                     "not test_xautoclaim "
-                     ;; These tests cause the following error: "Error 111
-                     ;; connecting to localhost:6380. Connection refused."
-                     ;; (see: https://github.com/redis/redis-py/issues/2109).
-                     "test_sync"
-                     "test_psync"
-                     ;; Same with: "Error 111 connecting to
-                     ;; localhost:6479. Connection refused."
-                     "test_tfcall"
-                     "test_tfunction_load_delete"
-                     "test_tfunction_list"
-                     ;; AssertionError: assert 3 == 2
-                     "test_acl_list")
+                    (append
+                     (list
+                      ;; The autoclaim test fails with "AssertionError: assert
+                      ;; [b'0-0', [], []] == [b'0-0', []]".
+                      "not test_xautoclaim "
+                      ;; These tests cause the following error: "Error 111
+                      ;; connecting to localhost:6380. Connection refused."
+                      ;; (see: https://github.com/redis/redis-py/issues/2109).
+                      "test_sync"
+                      "test_psync"
+                      ;; Same with: "Error 111 connecting to
+                      ;; localhost:6479. Connection refused."
+                      "test_tfcall"
+                      "test_tfunction_load_delete"
+                      "test_tfunction_list"
+                      ;; AssertionError: assert 3 == 2
+                      "test_acl_list")
+                     ;; XXX: This test occasionally fails on i686-linux
+                     (if (string-prefix? "i686" (%current-system))
+                         '("test_geopos")
+                         '()))
                     " and not "))
       #:phases
       #~(modify-phases %standard-phases
-- 
2.49.0